@@ -16,14 +16,13 @@ def run(infile):
 				tdoc = spacy.from_json(arr) 
 				for i,snt in enumerate(tdoc.sents):
 					doc = snt.as_doc() 
-					postag = "_^ " + ' '.join([f"{t.text}_{t.lemma_}_{t.pos_}_{t.tag_}" if t.text == t.text.lower() else f"{t.text}_{t.text.lower()}_{t.lemma_}_{t.pos_}_{t.tag_}" for t in doc])
-					fw.write(json.dumps({'_id': f"{did}-{i}-postag", '_source': {"postag":postag, 'url':url, 'tm': arr.get('info',{}).get('tm','')} }) + "\n") 
+					postag = "_^ " + ' '.join([ f"_{t.pos_}_{t.tag_}" if t.pos_ in ('PROPN','NUM','X','SPACE','PUNCT') else f"{t.text.lower()}_{t.lemma_}_{t.pos_}_{t.tag_}" for t in doc])
+					fw.write(json.dumps({'_id': f"{did}-{i}-postag", '_source': {"postag":postag, "sent": snt.text.strip(), 'url':url, 'tm': arr.get('info',{}).get('tm','')} }) + "\n") 
 			except Exception as e:
 				print ("ex:", e, sid, line) 
 	os.system(f"gzip -f -9 {outfile}")
 	print(f"{infile} is finished, \t| using: ", time.time() - start) 
 
-
 if __name__	== '__main__':
 	import fire 
 	fire.Fire(run)
